@@ -37,7 +37,7 @@
 /* #undef CONDUIT_GIT_SHA1_ABBREV */
 /* #undef CONDUIT_GIT_TAG */
 
-#define CONDUIT_SYSTEM_TYPE "Linux-6.12.61-1-lts"
+#define CONDUIT_SYSTEM_TYPE "Linux-6.18.7-arch1-1"
 
 #define CONDUIT_CPP_COMPILER "/usr/bin/c++"
 
